<?php

require_once "XML/Util.php";

//    base uri of installed directory of wawawa.
//    TODO : this uri is pseud-value. you should implement
//    dynamic value wherever wawawa is installed.
define( "RSS_BASEURL", ((getenv('SERVER_PORT')==443)?'https://':'http://').getenv('HTTP_HOST')."/rss/" );
 
/**
 *    this class generates RSS document.
 *    for the moment, the document generated by this class
 *    is compatible with RSS 1.0( http://web.resource.org/rss/1.0/spec )
 */
class RSSGenerator {
     
    var $channel;            //    channel element
    var $item;               //    item elements
    var $image;              //    image element
    var $textinput;          //    textinput element
    var $generated_rss;      //    finally, we get this value;
    var $error;              //    when error occurs, this value is set.

   /*
    *    Constructor. required field in all version must be set.
    */
    function RSSGenerator( $channelElements, $imageElements, $itemElements, $textInputElements ) {
     
        if( $channelElements == NULL || $itemElements == NULL ) {
            $this->error = new RSS_Generate_Error( "please dont set null paramator." );
            return;
        }
         
        //     build every element.
        $this->setChannel( $channelElements, $imageElements, $itemElements, $textInputElements );
    }
      
     //
     //    Elements which require multiple attributes must be build
     //    by independent method.
     //
      
     /*
      *    Use this method to build <channel> element which
      *    is required one in RSS 1.0.
      */
     function setChannel( $channelSubElements, $imageSubElements, $itemSubElements, $textInputSubElements ) {
          
         if( !channelParamCheck( $channelSubElements ) {
              return;
         }
 
         // 
         //    from here, build required elements
         //    
         $this->channel  = XML_Util::createStartElement( "channel", array( "rdf:about" => RSS_BASEURL ) );
         $this->channel .= XML_Util::createTag( "title"  , NULL,  $channelSubElements["title"] );
         $this->channel .= XML_Util::createTag( "link"   , NULL,  $channelSubElements["link"] );
         $this->channel .= XML_Util::createTag( "description", NULL, $channelSubElements["description"] );

         //    build <items> element
         $items_contents .= XML_Util::createStartElement( "items" );
         $items_contents .= XML_Util::createStartElement( "rdf:Seq" );
         $items_array = $channelSubElements["items"];
         if( !is_array( $items_array ) ) {
             $this->error = new RSS_Generate_Error( "error: the value of the key 'item' must be an array" );
             return;
         } else {
             foreach( $items_array as $value ) {
                 $items_contents .= XML_Util::createTag( "rdf:li" array( "resource" => $value["items_resource"] ) );
                 $this->setItem( $value );
             }
         }
         $items_contents .= XML_Util::createEndElement( "rdf:Seq" );
         $items_contents .= XML_Util::createEndElement( "items" );
         $this->channel .= $items_contents;


         // 
         //    from here, build optional elements
         //

         
         //    build <image> element
         //    for the moment, this class can build one <image> element.
         if( $imageSubElements != NULL ) {

             if( !is_array( $imageSubElements ) ) {
                 $this->error = RSS_Genarate_Error( "parameter of image Elements must be an array" );
                 return;
             }

             foreach( $imageSubElements as $imageValue ) {
                 $image_resource = $imageValue["image_resource"];
                 if( $image_resource == NULL ) {
                     $this->error = new RSS_Generate_Error( "image resource value is missing" );
                     return;
                 }
                 $this->channel .= XML_Util::createTag( "image" array( "rdf:resource" => $image_resource ) );
             
                 //    create image element that is outside channel element.
                 $this->setImage( $image_array );
             }              
         }

         //    build <textinput> element
         if( $textinputSubElements != NULL ) {

             if( !is_array( $textinputSubElements ) ) {
                  $this->error = new RSS_Generate_Error( "parameter of textinput must be array" );
                  return;
             }

             foreach( $textinputSubElements as $textinputValue ) {
                 $textinput_resource = $textinputValue["textinput_resource"];
                 if( $textinput_resource == NULL ) {
                     $this->error = new RSS_Generate_Error( "textinput resource value is missing" );
                     return;
                 }
                 $this->channel .= XML_Util::createTag( "textinput" array( "rdf:resource" => $textinput_resource ) );
                                                                                                                                               
                 //    create image element that is outside channel element.
                 $this->setTextInput( $textinputValue );
             }
         }

         return;
     }
      
     /*
      *    this method build <item> element outside channel element.
      *    you dont have to call this method from outside this class.
      */
     function setItem( $itemSubElements ) {
     
        if( !is_array( $itemSubElements ) {
            $this->error = new RSS_Generate_Error( "the parameter of setitem must be array" );
            return;
        }

        $item_title = $itemSubElements["item_title"];
        $item_link = $itemSubElements["item_link"];
        $item_description = $itemSubElements["item_description"];

        //    build item elements
        if ( $this->image == NULL ) {
            $this->image .= "";
        }
        $this->item .= XML_Util::createStartElement ( "item" );
        $this->item .= XML_Util::createTag( "title", NULL, $itemSubElements["item_title"] );
        $this->item .= XML_Util::createTag( "link" , NULL, $itemSubElements["item_link"]  );
        if( $itemSubElements["item_description"] != NULL ) {
            $this->item .= XML_Util::createTag( "description", NULL, $itemSubElements["item_description"] );
        }
        $this->item .= XML_Util::createEndElement( "item" );
                  
        return;      
     }

     /*
      *    this method build <image> element outside channel element.
      *    you dont have to call this method from outside this class.
      */
     function setImage( $image_array ) {

         $image_title = $image_array["image_title"];
         $image_link = $image_array["image_link"];
         $image_url = $image_array["image_url"];
                                                                                                                                               
         if( $image_title == NULL || $image_link == NULL || $image_url == NULL ) {
             $this->error = RSS_Generate_Error( "image tag exists, but title or link or url subelement is missing" );
             return;
         }

         $image_about = $image_array["image_about"];

         if( trim( $image_about ) != $image_array["image_resource"] ) {
             $this->error = new RSS_Generate_Error( "rdf:about attribute must be equal to rdf:resource" );
             return;
         }
                                                                                                                                               
         $this->image  = XML_Util::createStartElement ( "image", array( "rdf:about" => $image_array["image_about"] ) );
         $this->image .= XML_Util::createTag( "title", NULL, $image_title );
         $this->image .= XML_Util::createTag( "link", NULL, $image_link );
         $this->image .= XML_Util::createTag( "url", NULL, $image_url );
         $this->image .= XML_Util::createEndElement( "image" );
 
         return;
     }
      

     /*
      *    this method build <textinput> element outside channel element.
      *    you dont have to call this method from outside this class.
      */
     function setTextInput( $textinput_array ) {

         $textinput_title = $textinput_array["textinput_title"];
         $textinput_description = $textinput_array["textinput_description"];
         $textinput_name = $textinput_array["textinput_name"];
         $textinput_link = $textinput_array["textinput_link"];

         if( $textinput_title == NULL || $textinput_description == NULL
          || $textinput_name  == NULL || $textinput_link == NULL ) {
             $this->error = RSS_Generate_Error( "the required attribute of textinput elements is missing" );
             return;
         }

         $textinput_about = $textinput_array[ "textinput_about" ];

         if( trim( $textinput_about ) != $textinput_array["textinput_resource"] ) {
             $this->error = new RSS_Generate_Error( "rdf:about attribute must be equal to rdf:resource" );
             return;
         }
         
         $this->textinput  = XML_Util::createStartElement ( "textinput", array( "rdf:about" => $textinput_about ) );
         $this->textinput .= XML_Util::createTag( "title", NULL, $textinput_title );
         $this->textinput .= XML_Util::createTag( "link", NULL, $textinput_link );
         $this->textinput .= XML_Util::createTag( "name", NULL, $textinput_name );
         $this->textinput .= XML_Util::createTag( "description", NULL, $textinput_description );
         $this->textinput .= XML_Util::createEndElement( "textinput" );
         
         return;
     }

      
     //    finally,  we build and get XML Document.
     function getRSS() {
          
         //    set required field
         $this->generated_rss  = "<?xml version="1.0"?>\n";
         $this->generated_rss .= "<rdf:RDF>\n";
         $this->generated_rss .= $this->channel.$this->image.$this->item.$this->textinput;
         $this->generated_rss .= "<rdf:RDF>";
         return $_generated_rss;
     }
      
     function isError() {
         if( $_error != NULL ) {
             return TRUE;
         }
         return FALSE;
     }

     function channelParamCheck( $subElements ) {

         //    check required elements
         if( !in_array( "title", $subElements )
          || !in_array( "link", $subElements )
          || !in_array( "descripsion", $subElements )
          || !in_array( "items", $subElements ) ) {
             $this->error = new RSS_Generate_Error( "syntax error: title, link, descripsion, items element are required in <channel> element.\n" );
             return FALSE;
         }
                                                                                
         //    length check.(required elements)
         if( strlen( $subElements["title"] ) > 40
          || strlen( $subElements["link"] ) > 500
          || strlen( $subElements["description"] ) > 500 ) {
             $this->error = new RSS_Generate_Error( "syntax error: length of title or link or description is out of range" );
             return FALSE;
         }

         return TRUE;
     }

}
  
class RSS_Generate_Error {
     
    var $error_message;
     
    RSS_Generate_Error( $message ) {
        $this->$error_message = $message;
    }
     
     function getMessage() {
        return $error_message;
    }
}
 
?>
