<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | PHP version 4.0                                                      |
// +----------------------------------------------------------------------+
// | Copyright (c) 1997, 1998, 1999, 2000, 2001 The PHP Group             |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the PHP license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available at through the world-wide-web at                           |
// | http://www.php.net/license/2_02.txt.                                 |
// | If you did not receive a copy of the PHP license and are unable to   |
// | obtain it through the world-wide-web, please send a note to          |
// | license@php.net so we can mail you a copy immediately.               |
// +----------------------------------------------------------------------+
// | Authors: Adam Daniel <adaniel1@eesus.jnj.com>                        |
// |          Bertrand Mansion <bmansion@mamasam.com>                     |
// +----------------------------------------------------------------------+
//

require_once 'HTML/QuickForm/input.php';

class HTML_QuickForm_account extends HTML_QuickForm_input
{
    var $_account = "";

    function HTML_QuickForm_account($elementName=null, $elementLabel=null, $account=null, $attributes=null)
    {
        HTML_QuickForm_element::HTML_QuickForm_element($elementName, $elementLabel, $attributes);
        $this->_type = 'account';
        $this->setValue($account);
    } //end constructor
    
    // }}}
    // {{{ setName()

    /**
     * Sets the input field name
     * 
     * @param     string    $name   Input field name attribute
     * @since     1.0
     * @access    public
     * @return    void
     * @throws    
     */
    function setName($name)
    {
        $this->updateAttributes(array('name'=>$name));
    } //end func setName
    
    // }}}
    // {{{ getName()

    /**
     * Returns the element name
     * 
     * @since     1.0
     * @access    public
     * @return    string
     * @throws    
     */
    function getName()
    {
        return $this->getAttribute('name');
    } //end func getName

    // }}}
    // {{{ setValue()

    /**
     * Sets value for textarea element
     * 
     * @param     string    $value  Value for password element
     * @since     1.0
     * @access    public
     * @return    void
     * @throws    
     */
    function setValue($value)
    {
      if(is_a($value,'Person')) 
        $this->_account = $value;
      else
	$this->_account = account2person($value);

        return;
    } //end func setValue
    
    // }}}
    // {{{ getValue()

    /**
     * Returns the value of the form element
     *
     * @since     1.0
     * @access    public
     * @return    void
     * @throws    
     */
    function getValue()
    {
      
        return $this->_account->account;
    } // end func getValue

    
    // }}}
    // {{{ toHtml()

    /**
     * Returns the account & link element in HTML
     * 
     * @since     1.0
     * @access    public
     * @return    string
     * @throws    
     */
    function toHtml()
    {
        $tabs = $this->_getTabs();
        $html = sprintf('%s<input type="hidden" name="%s" value="%s"/><a href="account.php?account=%s">%s</a> (%s %s)',$tabs,$this->getName(),htmlspecialchars($this->_account->account),$this->_account->account,$this->_account->nick,$this->_account->firstname,$this->_account->surname);
        return $html;
    } //end func toHtml
    
    // }}}
    // {{{ getFrozenHtml()

    /**
     * Returns the value of field without HTML tags (in this case, value is changed to a mask)
     * 
     * @since     1.0
     * @access    public
     * @return    string
     * @throws    
     */
    function getFrozenHtml()
    {
        $tabs = $this->_getTabs();
        $html = sprintf('!%s!<a href="account.php?account=%s">%s</a> (%s %s)',$tabs,$this->_account->account,$this->_account->nick,$this->_account->firstname,$this->_account->surname);
        return $html;
    } //end func getFrozenHtml

    // }}}

} //end class HTML_QuickForm_textarea


class HTML_QuickForm_keyword extends HTML_QuickForm_input
{
    var $_keyword = "";

    function HTML_QuickForm_keyword($elementName=null, $elementLabel=null, $keyword=null, $attributes=null)
    {
        HTML_QuickForm_element::HTML_QuickForm_element($elementName, $elementLabel, $attributes);
        $this->_type = 'keyword';
        $this->setValue($keyword);
    } //end constructor
    
    // }}}
    // {{{ setName()

    /**
     * Sets the input field name
     * 
     * @param     string    $name   Input field name attribute
     * @since     1.0
     * @access    public
     * @return    void
     * @throws    
     */
    function setName($name)
    {
        $this->updateAttributes(array('name'=>$name));
    } //end func setName
    
    // }}}
    // {{{ getName()

    /**
     * Returns the element name
     * 
     * @since     1.0
     * @access    public
     * @return    string
     * @throws    
     */
    function getName()
    {
        return $this->getAttribute('name');
    } //end func getName

    // }}}
    // {{{ setValue()

    /**
     * Sets value for textarea element
     * 
     * @param     string    $value  Value for password element
     * @since     1.0
     * @access    public
     * @return    void
     * @throws    
     */
    function setValue($value)
    {
      if(is_a($value,'Keyword')) 
        $this->_keyword = $value;
      else
	$this->_keyword = keywordid2keyword($value);

        return;
    } //end func setValue
    
    // }}}
    // {{{ getValue()

    /**
     * Returns the value of the form element
     *
     * @since     1.0
     * @access    public
     * @return    void
     * @throws    
     */
    function getValue()
    {
      
        return $this->_keyword->id;
    } // end func getValue

    
    // }}}
    // {{{ toHtml()

    /**
     * Returns the keyword & link element in HTML
     * 
     * @since     1.0
     * @access    public
     * @return    string
     * @throws    
     */
    function toHtml()
    {
        $tabs = $this->_getTabs();
        $html = sprintf('%s<input type="hidden" name="%s" value="%s"/>%s',$tabs,$this->getName(),htmlspecialchars($this->_keyword->id),htmlspecialchars($this->_keyword->keyword));
        return $html;
    } //end func toHtml
    
    // }}}
    // {{{ getFrozenHtml()

    /**
     * Returns the value of field without HTML tags (in this case, value is changed to a mask)
     * 
     * @since     1.0
     * @access    public
     * @return    string
     * @throws    
     */
    function getFrozenHtml()
    {
        $tabs = $this->_getTabs();
        $html = sprintf('%s<input type="hidden" name="%s" value="%s"/>%s',$tabs,$this->getName(),htmlspecialchars($this->_keyword->id),htmlspecialchars($this->_keyword->keyword));
        return $html;
    } //end func getFrozenHtml

    // }}}

} //end class HTML_QuickForm_textarea

?>
